HtmlDiagnose
===============
A web page HTML format diagnoser

Install
===============
```bash
 pip install HtmlDiagnose
```

Use
===============
run command:

```bash
 python -m HtmlDiagnose https://www.baidu.com
```
more help:
```bash
 python -m HtmlDiagnose -h
```